import { ChangeHistoryAction } from '../utils';
import { MorphLink } from './MorphLink';
export interface MorphParameters {
    base?: string;
    waitForHeadToLoad?: boolean;
    cachePages?: boolean;
    trailingSlash?: boolean;
}
export interface MorphNavigationEntry {
    pathname: string;
    isCached: boolean;
    state?: any;
}
export interface MorphTransitionEntry extends MorphNavigationEntry {
    newDocument: Document;
}
export interface MorphChildrenActionEntry {
    morphElement: HTMLElement;
    pathname: string;
    isCached: boolean;
    state?: any;
}
export interface MorphPreprocessorEntry extends MorphNavigationEntry {
    resolve: () => void;
    reject: () => void;
}
export type MorphPreprocessor = (entry: MorphPreprocessorEntry) => void;
export type MorphNavigationCallback = (entry: MorphNavigationEntry) => void;
export type MorphPostprocessor = MorphNavigationCallback;
export interface MorphScrollState {
    x: number;
    y: number;
    selector: string;
}
export interface MorphNavigateOptions {
    historyAction?: ChangeHistoryAction;
    state?: any;
    saveScrollState?: MorphScrollState;
    saveDocumentState?: boolean;
    restoreScrollState?: boolean;
    restoreDocumentState?: boolean;
}
export interface MorphEvents {
    morphStart: CustomEvent<MorphTransitionEntry>;
    morphComplete: CustomEvent<MorphTransitionEntry>;
    morphNewChildrenAdded: CustomEvent<MorphChildrenActionEntry>;
    morphOldChildrenRemoved: CustomEvent<MorphChildrenActionEntry>;
}
export declare class Morph {
    #private;
    preprocessor?: MorphPreprocessor;
    postprocessor?: MorphPostprocessor;
    constructor(parameters?: MorphParameters);
    get currentPathname(): string;
    get previousPathname(): string | undefined;
    get currentState(): any;
    get links(): MorphLink[];
    normalizePath(path: string): {
        leaf: string;
        pathname: string;
        parameters: string;
        hash: string;
    };
    prefetch(path: string): Promise<Document>;
    navigate(path: string, { historyAction, state, saveScrollState, saveDocumentState, restoreDocumentState, restoreScrollState, }?: MorphNavigateOptions): Promise<void>;
    addLink(element: HTMLAnchorElement): void;
    addLinks(elements: Array<HTMLAnchorElement>): void;
    removeLink(element: HTMLAnchorElement): void;
    findLinks(): void;
}
declare global {
    interface DocumentEventMap extends MorphEvents {
    }
}
