import { CSSProperty } from '../css-property';
import { Store } from '../store';
import { Damped } from '../animation';
export interface ScrollSegmentEvents {
    scrollSegmentCapture: CustomEvent;
    scrollSegmentCaptureFromStart: CustomEvent;
    scrollSegmentCaptureFromFinish: CustomEvent;
    scrollSegmentRelease: CustomEvent;
    scrollSegmentReleaseFromStart: CustomEvent;
    scrollSegmentReleaseFromFinish: CustomEvent;
}
export interface ScrollSegmentContainer {
    element: HTMLElement;
    currentScrollValue: number;
    vertical: boolean;
    onScroll(callback: Function): void;
    offScroll(callback: Function): void;
}
export interface ScrollSegmentContainerElement extends Omit<ScrollSegmentContainer, 'element'>, HTMLElement {
}
export declare class ScrollSegmentElement extends HTMLElement {
    #private;
    constructor();
    get scrollContainer(): ScrollSegmentContainerElement | ScrollSegmentContainer;
    set scrollContainer(value: ScrollSegmentContainerElement | ScrollSegmentContainer);
    get distanceOffsetCSSProperty(): CSSProperty<number>;
    get startOffsetCSSProperty(): CSSProperty<number>;
    get captureOnceCSSProperty(): CSSProperty<boolean>;
    get capturedCSSProperty(): CSSProperty<string>;
    get releasedCSSProperty(): CSSProperty<string>;
    get capturedFromStartCSSProperty(): CSSProperty<string>;
    get capturedFromFinishCSSProperty(): CSSProperty<string>;
    get releasedFromStartCSSProperty(): CSSProperty<string>;
    get releasedFromFinishCSSProperty(): CSSProperty<string>;
    get passedVarCSSProperty(): CSSProperty<string>;
    get progressVarCSSProperty(): CSSProperty<string>;
    get animationVarTypeCSSProperty(): CSSProperty<"target" | "current">;
    get distanceVarCSSProperty(): CSSProperty<string>;
    get startVarCSSProperty(): CSSProperty<string>;
    get finishVarCSSProperty(): CSSProperty<string>;
    get disabledCSSProperty(): CSSProperty<boolean>;
    get dampingCSSProperty(): CSSProperty<number>;
    get massCSSProperty(): CSSProperty<number>;
    get stiffnessCSSProperty(): CSSProperty<number>;
    get targetCSSProperty(): CSSProperty<string>;
    get isCaptured(): Store<boolean>;
    get isReleased(): Store<boolean>;
    get isCapturedFromStart(): Store<boolean>;
    get isReleasedFromStart(): Store<boolean>;
    get isCapturedFromFinish(): Store<boolean>;
    get isReleasedFromFinish(): Store<boolean>;
    get directionPosition(): number;
    get directionSize(): number;
    get passed(): Damped;
    get progress(): number;
    get start(): number;
    get finish(): number;
    get distance(): number;
    get isCapturedOnce(): boolean;
    get isDisabled(): boolean;
    resize(): void;
    tick(): void;
    disable(): void;
    enable(): void;
    protected connectedCallback(): void;
    protected disconnectedCallback(): void;
    protected removeVar(name: string | undefined): void;
    protected setVar(name: string | undefined, value: string | number): void;
    protected getDistance(): number;
    protected getStart(): number;
    protected findAnotherScrollEntries: () => void;
}
declare global {
    interface HTMLElementTagNameMap {
        'scroll-segment': ScrollSegmentElement;
    }
    interface HTMLElementEventMap extends ScrollSegmentEvents {
    }
}
