import { Damped, TweenedOptions } from '../animation';
import { Store } from '../store';
import { Axes2D } from '../utils';
import { CSSProperty } from '../css-property';
import { ScrollSection } from './ScrollSection';
export type ScrollLine = 'start' | 'end' | null;
export interface ScrollEvents {
    scrollSectionsChange: CustomEvent;
    scrollLine: CustomEvent<{
        line: ScrollLine;
    }>;
}
export type ScrollBehaviour = 'smooth' | 'instant';
export interface ScrollSetOptions {
    behaviour?: ScrollBehaviour;
    tween?: {
        easing?: TweenedOptions['easing'] | false;
        duration?: number | false;
    };
}
export declare class ScrollElement extends HTMLElement {
    #private;
    constructor();
    get damped(): Damped;
    get controlsCSSProperty(): CSSProperty<boolean>;
    get axisCSSProperty(): CSSProperty<Axes2D>;
    get reverseCSSProperty(): CSSProperty<boolean>;
    get directionCSSProperty(): CSSProperty<number>;
    get pagesCSSProperty(): CSSProperty<number>;
    get splitCSSProperty(): CSSProperty<boolean>;
    get sectionalCSSProperty(): CSSProperty<boolean>;
    get easingCSSProperty(): CSSProperty<false | "linear" | "easeInQuad" | "easeOutQuad" | "easeInOutQuad" | "easeInCubic" | "easeOutCubic" | "easeInOutCubic" | "easeInQuart" | "easeOutQuart" | "easeInOutQuart" | "easeInQuint" | "easeOutQuint" | "easeInOutQuint" | "easeInExpo" | "easeOutExpo" | "easeInOutExpo">;
    get durationCSSProperty(): CSSProperty<number | false>;
    get autoSizeCSSProperty(): CSSProperty<boolean>;
    get wheelMaxDeltaCSSProperty(): CSSProperty<boolean>;
    get dragInertionCSSProperty(): CSSProperty<number>;
    get sectionsInViewCSSProperty(): CSSProperty<number>;
    get loopCSSProperty(): CSSProperty<boolean>;
    get dampingCSSProperty(): CSSProperty<number>;
    get massCSSProperty(): CSSProperty<number>;
    get stiffnessCSSProperty(): CSSProperty<number>;
    get mouseDragCSSProperty(): CSSProperty<boolean>;
    get sectionDistanceScaleCSSProperty(): CSSProperty<number>;
    get autoplayCSSProperty(): CSSProperty<number>;
    get autoplayPauseDurationCSSProperty(): CSSProperty<number>;
    get autoplayUserDirectionCSSProperty(): CSSProperty<boolean>;
    get classesCSSProperty(): CSSProperty<boolean>;
    get currentIndexStartOffsetCSSProperty(): CSSProperty<number>;
    get currentIndexEndOffsetCSSProperty(): CSSProperty<number>;
    get focusDelayCSSProperty(): CSSProperty<number>;
    get focusDurationCSSProperty(): CSSProperty<number>;
    get disabledCSSProperty(): CSSProperty<boolean>;
    get hibernatedCSSProperty(): CSSProperty<boolean>;
    get currentScrollValue(): number;
    get targetScrollValue(): number;
    get contentWrapperElement(): HTMLElement;
    get contentElement(): HTMLElement;
    get sections(): ScrollSection[];
    get position(): number;
    get contentPosition(): number;
    get viewportSize(): number;
    get scrollSize(): number;
    get gap(): number;
    get counter(): Store<number>;
    get limit(): number;
    get distance(): number;
    get loopDistance(): number;
    get hasOverflow(): boolean;
    get overscroll(): number;
    get scrollLine(): ScrollLine;
    get vertical(): boolean;
    get currentProgress(): number;
    get targetProgress(): number;
    get scrollWidth(): number;
    get scrollHeight(): number;
    onScroll(...parameters: Parameters<Damped['subscribe']>): () => void;
    offScroll(...parameters: Parameters<Damped['unsubscribe']>): void;
    range(from: number, distance: number, margin?: number): number;
    curve(from: number, distance: number, margin?: number): number;
    visible(from: number, distance: number, margin?: number): boolean;
    scrollToSection(sectionIndex: number, options?: ScrollSetOptions): void;
    shiftSections(step: number, options?: ScrollSetOptions): void;
    setPosition(value: number, options?: ScrollSetOptions): void;
    shiftPosition(value: number, options?: ScrollSetOptions): void;
    protected connectedCallback(): void;
    protected disconnectedCallback(): void;
}
declare global {
    interface HTMLElementTagNameMap {
        'e-scroll': ScrollElement;
    }
    interface HTMLElementEventMap extends ScrollEvents {
    }
}
